@@ -117,6 +117,7 @@ def cli():
 @click.option(
     "--wait", type=int, help="Wait this many milliseconds before taking the screenshot"
 )
+@click.option("--wait-for", help="Wait until this JS expression returns true")
 @click.option(
     "--timeout",
     type=int,
@@ -151,6 +152,7 @@ def shot(
     retina,
     quality,
     wait,
+    wait_for,
     timeout,
     interactive,
     devtools,
@@ -198,6 +200,7 @@ def shot(
         "height": height,
         "quality": quality,
         "wait": wait,
+        "wait_for": wait_for,
         "timeout": timeout,
         "padding": padding,
         "retina": retina,
@@ -327,7 +330,7 @@ def multi(
         - output: example.png
           url: http://www.example.com/
 
-    https://github.com/simonw/shot-scraper/blob/main/README.md#multi
+    https://shot-scraper.datasette.io/en/stable/multi.html
     """
     shots = yaml.safe_load(config)
     if shots is None:
@@ -574,9 +577,7 @@ def install(browser):
 )
 @browser_option
 @user_agent_option
-@click.option(
-    "--devtools", is_flag=True, help="Open browser DevTools"
-)
+@click.option("--devtools", is_flag=True, help="Open browser DevTools")
 def auth(url, context_file, browser, user_agent, devtools):
     """
     Open a browser so user can manually authenticate with the specified site,
@@ -639,6 +640,7 @@ def take_shot(
         output = filename_for_url(url, ext="png", file_exists=os.path.exists)
     quality = shot.get("quality")
     wait = shot.get("wait")
+    wait_for = shot.get("wait_for")
     padding = shot.get("padding") or 0
 
     selectors = shot.get("selectors") or []
@@ -675,10 +677,14 @@ def take_shot(
 
     if wait:
         time.sleep(wait / 1000)
+
     javascript = shot.get("javascript")
     if javascript:
         _evaluate_js(page, javascript)
 
+    if wait_for:
+        page.wait_for_function(wait_for)
+
     screenshot_args = {}
     if quality:
         screenshot_args.update({"quality": quality, "type": "jpeg"})
